@@ -37,6 +37,18 @@ static double convertTemp(double temp, const QString &unit)
     }
 };
 
-enum class WindDirection { N, NW, W, SW, S, SE, E, NE };
-enum class Backend { NMI, OWM };
+enum class WindDirection {
+    N,
+    NW,
+    W,
+    SW,
+    S,
+    SE,
+    E,
+    NE
+};
+enum class Backend {
+    NMI,
+    OWM
+};
 }
